.tree-menu
  display: block
  ul.children, ul.items
    margin-left: 10px
  ul li.menu
    &.closed ul
      display: none
    &.open ul
      display: block
    &.active ul
      display: block
      li.menu a
        color: white
    